@@ -1,17 +1,19 @@
 #!/usr/bin/python
 # -*- coding: utf-8 -*-
-# $Id: test_dbapi20.py 995 2019-04-25 14:10:20Z cito $
 
-try:
-    import unittest2 as unittest  # for Python < 2.7
-except ImportError:
-    import unittest
+import gc
+import sys
+import unittest
+
+from datetime import date, time, datetime, timedelta
+from uuid import UUID as Uuid
 
 import pgdb
 
 try:
     from . import dbapi20
 except (ImportError, ValueError, SystemError):
+    # noinspection PyUnresolvedReferences
     import dbapi20
 
 # We need a database to test against.
@@ -21,29 +23,18 @@ dbname = 'dbapi20_test'
 dbhost = ''
 dbport = 5432
 try:
-    from .LOCAL_PyGreSQL import *
+    from .LOCAL_PyGreSQL import *  # noqa: F401
 except (ImportError, ValueError):
     try:
-        from LOCAL_PyGreSQL import *
+        from LOCAL_PyGreSQL import *  # noqa: F401
     except ImportError:
         pass
 
-import gc
-import sys
-
-from datetime import date, time, datetime, timedelta
-from uuid import UUID as Uuid
-
-try:  # noinspection PyUnresolvedReferences
+try:  # noinspection PyUnboundLocalVariable,PyUnresolvedReferences
     long
 except NameError:  # Python >= 3.0
     long = int
 
-try:
-    from collections import OrderedDict
-except ImportError:  # Python 2.6 or 3.0
-    OrderedDict = None
-
 
 class PgBitString:
     """Test object with a PostgreSQL representation as Bit String."""
@@ -52,20 +43,19 @@ class PgBitString:
         self.value = value
 
     def __pg_repr__(self):
-         return "B'{0:b}'".format(self.value)
+        return "B'{0:b}'".format(self.value)
 
 
 class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
 
     driver = pgdb
     connect_args = ()
-    connect_kw_args = {'database': dbname,
-        'host': '%s:%d' % (dbhost or '', dbport or -1)}
+    connect_kw_args = {
+        'database': dbname, 'host': '%s:%d' % (dbhost or '', dbport or -1)}
 
     lower_func = 'lower'  # For stored procedure test
 
     def setUp(self):
-        # Call superclass setUp in case this does something in the future
         dbapi20.DatabaseAPI20Test.setUp(self)
         try:
             con = self._connect()
@@ -74,7 +64,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             import pg
             try:  # first try to log in as superuser
                 db = pg.DB('postgres', dbhost or None, dbport or -1,
-                    user='postgres')
+                           user='postgres')
             except Exception:  # then try to log in as current user
                 db = pg.DB('postgres', dbhost or None, dbport or -1)
             db.query('create database ' + dbname)
@@ -94,9 +84,18 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         con = self._connect()
         cur = con.cursor()
         cur.execute("select application_name from pg_stat_activity"
-            " where application_name = %s", (application_name,))
+                    " where application_name = %s", (application_name,))
         self.assertEqual(cur.fetchone(), (application_name,))
 
+    def test_connect_kwargs_with_special_chars(self):
+        special_name = 'Single \' and double " quote and \\ backslash!'
+        self.connect_kw_args['application_name'] = special_name
+        con = self._connect()
+        cur = con.cursor()
+        cur.execute("select application_name from pg_stat_activity"
+                    " where application_name = %s", (special_name,))
+        self.assertEqual(cur.fetchone(), (special_name,))
+
     def test_percent_sign(self):
         con = self._connect()
         cur = con.cursor()
@@ -145,7 +144,9 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
     def test_cursor_type(self):
 
         class TestCursor(pgdb.Cursor):
-            pass
+            @staticmethod
+            def row_factory(row):
+                return row  # not used
 
         con = self._connect()
         self.assertIs(con.cursor_type, pgdb.Cursor)
@@ -168,8 +169,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         class TestCursor(pgdb.Cursor):
 
             def row_factory(self, row):
-                return dict(('column %s' % desc[0], value)
-                    for desc, value in zip(self.description, row))
+                return {'column %s' % desc[0]: value
+                        for desc, value in zip(self.description, row)}
 
         con = self._connect()
         con.cursor_type = TestCursor
@@ -191,12 +192,13 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
 
     def test_build_row_factory(self):
 
+        # noinspection PyAbstractClass
         class TestCursor(pgdb.Cursor):
 
             def build_row_factory(self):
                 keys = [desc[0] for desc in self.description]
-                return lambda row: dict((key, value)
-                    for key, value in zip(keys, row))
+                return lambda row: {
+                    key: value for key, value in zip(keys, row)}
 
         con = self._connect()
         con.cursor_type = TestCursor
@@ -215,6 +217,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertIsInstance(res[1], dict)
         self.assertEqual(res[1], {'a': 3, 'b': 4})
 
+    # noinspection PyUnresolvedReferences
     def test_cursor_with_named_columns(self):
         con = self._connect()
         cur = con.cursor()
@@ -238,6 +241,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertEqual(res[1], (3, 4))
         self.assertEqual(res[1]._fields, ('one', 'two'))
 
+    # noinspection PyUnresolvedReferences
     def test_cursor_with_unnamed_columns(self):
         con = self._connect()
         cur = con.cursor()
@@ -245,21 +249,14 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         res = cur.fetchone()
         self.assertIsInstance(res, tuple)
         self.assertEqual(res, (1, 2, 3))
-        old_py = OrderedDict is None  # Python 2.6 or 3.0
-        # old Python versions cannot rename tuple fields with underscore
-        if old_py:
-            self.assertEqual(res._fields, ('column_0', 'column_1', 'column_2'))
-        else:
-            self.assertEqual(res._fields, ('_0', '_1', '_2'))
+        self.assertEqual(res._fields, ('_0', '_1', '_2'))
         cur.execute("select 1 as one, 2, 3 as three")
         res = cur.fetchone()
         self.assertIsInstance(res, tuple)
         self.assertEqual(res, (1, 2, 3))
-        if old_py:  # cannot auto rename with underscore
-            self.assertEqual(res._fields, ('one', 'column_1', 'three'))
-        else:
-            self.assertEqual(res._fields, ('one', '_1', 'three'))
+        self.assertEqual(res._fields, ('one', '_1', 'three'))
 
+    # noinspection PyUnresolvedReferences
     def test_cursor_with_badly_named_columns(self):
         con = self._connect()
         cur = con.cursor()
@@ -267,21 +264,15 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         res = cur.fetchone()
         self.assertIsInstance(res, tuple)
         self.assertEqual(res, (1, 2))
-        old_py = OrderedDict is None  # Python 2.6 or 3.0
-        if old_py:
-            self.assertEqual(res._fields, ('abc', 'column_1'))
-        else:
-            self.assertEqual(res._fields, ('abc', '_1'))
-        cur.execute('select 1 as snake_case, 2 as "CamelCase",'
+        self.assertEqual(res._fields, ('abc', '_1'))
+        cur.execute(
+            'select 1 as snake_case, 2 as "CamelCase",'
             ' 3 as "kebap-case", 4 as "_bad", 5 as "0bad", 6 as "bad$"')
         res = cur.fetchone()
         self.assertIsInstance(res, tuple)
         self.assertEqual(res, (1, 2, 3, 4, 5, 6))
-        # old Python versions cannot rename tuple fields with underscore
         self.assertEqual(res._fields[:2], ('snake_case', 'CamelCase'))
         fields = ('_2', '_3', '_4', '_5')
-        if old_py:
-            fields = tuple('column' + field for field in fields)
         self.assertEqual(res._fields[2:], fields)
 
     def test_colnames(self):
@@ -304,12 +295,13 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertIsInstance(types, list)
         self.assertEqual(types, ['int2', 'int4', 'int8'])
 
+    # noinspection PyUnresolvedReferences
     def test_description_fields(self):
         con = self._connect()
         cur = con.cursor()
         cur.execute("select 123456789::int8 col0,"
-            " 123456.789::numeric(41, 13) as col1,"
-            " 'foobar'::char(39) as col2")
+                    " 123456.789::numeric(41, 13) as col1,"
+                    " 'foobar'::char(39) as col2")
         desc = cur.description
         self.assertIsInstance(desc, list)
         self.assertEqual(len(desc), 3)
@@ -357,6 +349,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             self.assertEqual(type_info.type, 'c')  # composite
             self.assertEqual(type_info.category, 'C')  # composite
             cols = type_cache.get_fields('pg_type')
+            if cols[0].name == 'oid':  # PostgreSQL < 12
+                del cols[0]
             self.assertEqual(cols[0].name, 'typname')
             typname = type_cache[cols[0].type]
             self.assertEqual(typname, 'name')
@@ -393,7 +387,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             cur = con.cursor()
             type_cache = con.type_cache
             self.assertIs(type_cache.get_typecast('int4'), int)
-            cast_int = lambda v: 'int(%s)' % v
+            cast_int = lambda v: 'int(%s)' % v  # noqa: E731
             type_cache.set_typecast('int4', cast_int)
             query = 'select 2::int2, 4::int4, 8::int8'
             cur.execute(query)
@@ -455,16 +449,17 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
     def test_fetch_2_rows(self):
         Decimal = pgdb.decimal_type()
         values = ('test', pgdb.Binary(b'\xff\x52\xb2'),
-            True, 5, 6, 5.7, Decimal('234.234234'), Decimal('75.45'),
-            pgdb.Date(2011, 7, 17), pgdb.Time(15, 47, 42),
-            pgdb.Timestamp(2008, 10, 20, 15, 25, 35),
-            pgdb.Interval(15, 31, 5), 7897234)
+                  True, 5, 6, 5.7, Decimal('234.234234'), Decimal('75.45'),
+                  pgdb.Date(2011, 7, 17), pgdb.Time(15, 47, 42),
+                  pgdb.Timestamp(2008, 10, 20, 15, 25, 35),
+                  pgdb.Interval(15, 31, 5), 7897234)
         table = self.table_prefix + 'booze'
         con = self._connect()
         try:
             cur = con.cursor()
             cur.execute("set datestyle to iso")
-            cur.execute("create table %s ("
+            cur.execute(
+                "create table %s ("
                 "stringtest varchar,"
                 "binarytest bytea,"
                 "booltest bool,"
@@ -482,7 +477,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             for s in ('numeric', 'monetary', 'time'):
                 cur.execute("set lc_%s to 'C'" % s)
             for _i in range(2):
-                cur.execute("insert into %s values ("
+                cur.execute(
+                    "insert into %s values ("
                     "%%s,%%s,%%s,%%s,%%s,%%s,%%s,"
                     "'%%s'::money,%%s,%%s,%%s,%%s,%%s)" % table, values)
             cur.execute("select * from %s" % table)
@@ -515,7 +511,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             cur.execute("create table %s (i int primary key)" % table)
             cur.execute("insert into %s values (1)" % table)
             cur.execute("insert into %s values (2)" % table)
-            self.assertRaises(pgdb.IntegrityError, cur.execute,
+            self.assertRaises(
+                pgdb.IntegrityError, cur.execute,
                 "insert into %s values (1)" % table)
         finally:
             con.close()
@@ -545,6 +542,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         except pgdb.DatabaseError as error:
             self.assertTrue(isinstance(error, pgdb.DataError))
             # the SQLSTATE error code for division by zero is 22012
+            # noinspection PyUnresolvedReferences
             self.assertEqual(error.sqlstate, '22012')
 
     def test_float(self):
@@ -553,7 +551,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertTrue(isnan(nan) and not isinf(nan))
         self.assertTrue(isinf(inf) and not isnan(inf))
         values = [0, 1, 0.03125, -42.53125, nan, inf, -inf,
-            'nan', 'inf', '-inf', 'NaN', 'Infinity', '-Infinity']
+                  'nan', 'inf', '-inf', 'NaN', 'Infinity', '-Infinity']
         table = self.table_prefix + 'booze'
         con = self._connect()
         try:
@@ -597,11 +595,10 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             cur = con.cursor()
             cur.execute("set timezone = UTC")
             cur.execute("create table %s ("
-                "d date, t time,  ts timestamp,"
-                "tz timetz, tsz timestamptz)" % table)
+                        "d date, t time,  ts timestamp,"
+                        "tz timetz, tsz timestamptz)" % table)
             for n in range(3):
-                values = [dt.date(), dt.time(), dt,
-                    dt.time(), dt]
+                values = [dt.date(), dt.time(), dt, dt.time(), dt]
                 values[3] = values[3].replace(tzinfo=pgdb.timezone.utc)
                 values[4] = values[4].replace(tzinfo=pgdb.timezone.utc)
                 if n == 0:  # input as objects
@@ -613,16 +610,18 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
                     t = (dt.hour, dt.minute, dt.second, dt.microsecond)
                     z = (pgdb.timezone.utc,)
                     params = [pgdb.Date(*d), pgdb.Time(*t),
-                            pgdb.Timestamp(*(d + t)), pgdb.Time(*(t + z)),
-                            pgdb.Timestamp(*(d + t + z))]
+                              pgdb.Timestamp(*(d + t)), pgdb.Time(*(t + z)),
+                              pgdb.Timestamp(*(d + t + z))]
                 for datestyle in ('iso', 'postgres, mdy', 'postgres, dmy',
-                        'sql, mdy', 'sql, dmy', 'german'):
+                                  'sql, mdy', 'sql, dmy', 'german'):
                     cur.execute("set datestyle to %s" % datestyle)
                     if n != 1:
+                        # noinspection PyUnboundLocalVariable
                         cur.execute("select %s,%s,%s,%s,%s", params)
                         row = cur.fetchone()
                         self.assertEqual(row, tuple(values))
-                    cur.execute("insert into %s"
+                    cur.execute(
+                        "insert into %s"
                         " values (%%s,%%s,%%s,%%s,%%s)" % table, params)
                     cur.execute("select * from %s" % table)
                     d = cur.description
@@ -638,7 +637,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
                     self.assertEqual(d[4].type_code, pgdb.TIMESTAMP)
                     row = cur.fetchone()
                     self.assertEqual(row, tuple(values))
-                    cur.execute("delete from %s" % table)
+                    cur.execute("truncate table %s" % table)
         finally:
             con.close()
 
@@ -659,10 +658,11 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
                     param = pgdb.Interval(
                         td.days, 0, 0, td.seconds, td.microseconds)
                 for intervalstyle in ('sql_standard ', 'postgres',
-                        'postgres_verbose', 'iso_8601'):
+                                      'postgres_verbose', 'iso_8601'):
                     cur.execute("set intervalstyle to %s" % intervalstyle)
+                    # noinspection PyUnboundLocalVariable
                     cur.execute("insert into %s"
-                        " values (%%s)" % table, [param])
+                                " values (%%s)" % table, [param])
                     cur.execute("select * from %s" % table)
                     tc = cur.description[0].type_code
                     self.assertEqual(tc, pgdb.DATETIME)
@@ -672,14 +672,14 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
                     self.assertEqual(tc, pgdb.INTERVAL)
                     row = cur.fetchone()
                     self.assertEqual(row, (td,))
-                    cur.execute("delete from %s" % table)
+                    cur.execute("truncate table %s" % table)
         finally:
             con.close()
 
     def test_hstore(self):
         con = self._connect()
+        cur = con.cursor()
         try:
-            cur = con.cursor()
             cur.execute("select 'k=>v'::hstore")
         except pgdb.DatabaseError:
             try:
@@ -689,9 +689,9 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         finally:
             con.close()
         d = {'k': 'v', 'foo': 'bar', 'baz': 'whatever', 'back\\': '\\slash',
-            '1a': 'anything at all', '2=b': 'value = 2', '3>c': 'value > 3',
-            '4"c': 'value " 4', "5'c": "value ' 5", 'hello, world': '"hi!"',
-            'None': None, 'NULL': 'NULL', 'empty': ''}
+             '1a': 'anything at all', '2=b': 'value = 2', '3>c': 'value > 3',
+             '4"c': 'value " 4', "5'c": "value ' 5", 'hello, world': '"hi!"',
+             'None': None, 'NULL': 'NULL', 'empty': ''}
         con = self._connect()
         try:
             cur = con.cursor()
@@ -716,21 +716,23 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertEqual(result, d)
 
     def test_insert_array(self):
-        values = [(None, None), ([], []), ([None], [[None], ['null']]),
+        values = [
+            (None, None), ([], []), ([None], [[None], ['null']]),
             ([1, 2, 3], [['a', 'b'], ['c', 'd']]),
             ([20000, 25000, 25000, 30000],
-            [['breakfast', 'consulting'], ['meeting', 'lunch']]),
+             [['breakfast', 'consulting'], ['meeting', 'lunch']]),
             ([0, 1, -1], [['Hello, World!', '"Hi!"'], ['{x,y}', ' x y ']])]
         table = self.table_prefix + 'booze'
         con = self._connect()
         try:
             cur = con.cursor()
             cur.execute("create table %s"
-                " (n smallint, i int[], t text[][])" % table)
+                        " (n smallint, i int[], t text[][])" % table)
             params = [(n, v[0], v[1]) for n, v in enumerate(values)]
             # Note that we must explicit casts because we are inserting
             # empty arrays.  Otherwise this is not necessary.
-            cur.executemany("insert into %s values"
+            cur.executemany(
+                "insert into %s values"
                 " (%%d,%%s::int[],%%s::text[][])" % table, params)
             cur.execute("select i, t from %s order by n" % table)
             d = cur.description
@@ -781,8 +783,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         table = self.table_prefix + 'booze'
         record = self.table_prefix + 'munch'
         con = self._connect()
+        cur = con.cursor()
         try:
-            cur = con.cursor()
             cur.execute("create type %s as (name varchar, age int)" % record)
             cur.execute("create table %s (n smallint, r %s)" % (table, record))
             params = enumerate(values)
@@ -810,7 +812,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
 
     def test_select_record(self):
         value = (1, 25000, 2.5, 'hello', 'Hello World!', 'Hello, World!',
-            '(test)', '(x,y)', ' x y ', 'null', None)
+                 '(test)', '(x,y)', ' x y ', 'null', None)
         con = self._connect()
         try:
             cur = con.cursor()
@@ -846,7 +848,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         try:
             cur = con.cursor()
             params = (1, object())  # an object that cannot be handled
-            self.assertRaises(pgdb.InterfaceError, cur.execute,
+            self.assertRaises(
+                pgdb.InterfaceError, cur.execute,
                 "insert into %s values (%%s,%%s)" % table, params)
         finally:
             con.close()
@@ -858,7 +861,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         try:
             cur = con.cursor()
             # change decimal type globally to int
-            int_type = lambda v: int(float(v))
+            int_type = lambda v: int(float(v))  # noqa: E731
             self.assertTrue(pgdb.decimal_type(int_type) is int_type)
             cur.execute('select 4.25')
             self.assertEqual(cur.description[0].type_code, pgdb.NUMBER)
@@ -889,7 +892,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         try:
             query = 'select 2::int2, 4::int4, 8::int8'
             self.assertIs(pgdb.get_typecast('int4'), int)
-            cast_int = lambda v: 'int(%s)' % v
+            cast_int = lambda v: 'int(%s)' % v  # noqa: E731
             pgdb.set_typecast('int4', cast_int)
             con = self._connect()
             try:
@@ -976,32 +979,32 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
 
     def test_unicode_with_utf8(self):
         table = self.table_prefix + 'booze'
-        input = u"He wes Leovenaðes sone — liðe him be Drihten"
+        s = u"He wes Leovenaðes sone — liðe him be Drihten"
         con = self._connect()
+        cur = con.cursor()
         try:
-            cur = con.cursor()
             cur.execute("create table %s (t text)" % table)
             try:
                 cur.execute("set client_encoding=utf8")
-                cur.execute(u"select '%s'" % input)
+                cur.execute(u"select '%s'" % s)
             except Exception:
                 self.skipTest("database does not support utf8")
             output1 = cur.fetchone()[0]
-            cur.execute("insert into %s values (%%s)" % table, (input,))
+            cur.execute("insert into %s values (%%s)" % table, (s,))
             cur.execute("select * from %s" % table)
             output2 = cur.fetchone()[0]
-            cur.execute("select t = '%s' from %s" % (input, table))
+            cur.execute("select t = '%s' from %s" % (s, table))
             output3 = cur.fetchone()[0]
-            cur.execute("select t = %%s from %s" % table, (input,))
+            cur.execute("select t = %%s from %s" % table, (s,))
             output4 = cur.fetchone()[0]
         finally:
             con.close()
         if str is bytes:  # Python < 3.0
-            input = input.encode('utf8')
+            s = s.encode('utf8')
         self.assertIsInstance(output1, str)
-        self.assertEqual(output1, input)
+        self.assertEqual(output1, s)
         self.assertIsInstance(output2, str)
-        self.assertEqual(output2, input)
+        self.assertEqual(output2, s)
         self.assertIsInstance(output3, bool)
         self.assertTrue(output3)
         self.assertIsInstance(output4, bool)
@@ -1009,32 +1012,32 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
 
     def test_unicode_with_latin1(self):
         table = self.table_prefix + 'booze'
-        input = u"Ehrt den König seine Würde, ehret uns der Hände Fleiß."
+        s = u"Ehrt den König seine Würde, ehret uns der Hände Fleiß."
         con = self._connect()
         try:
             cur = con.cursor()
             cur.execute("create table %s (t text)" % table)
             try:
                 cur.execute("set client_encoding=latin1")
-                cur.execute(u"select '%s'" % input)
+                cur.execute(u"select '%s'" % s)
             except Exception:
                 self.skipTest("database does not support latin1")
             output1 = cur.fetchone()[0]
-            cur.execute("insert into %s values (%%s)" % table, (input,))
+            cur.execute("insert into %s values (%%s)" % table, (s,))
             cur.execute("select * from %s" % table)
             output2 = cur.fetchone()[0]
-            cur.execute("select t = '%s' from %s" % (input, table))
+            cur.execute("select t = '%s' from %s" % (s, table))
             output3 = cur.fetchone()[0]
-            cur.execute("select t = %%s from %s" % table, (input,))
+            cur.execute("select t = %%s from %s" % table, (s,))
             output4 = cur.fetchone()[0]
         finally:
             con.close()
         if str is bytes:  # Python < 3.0
-            input = input.encode('latin1')
+            s = s.encode('latin1')
         self.assertIsInstance(output1, str)
-        self.assertEqual(output1, input)
+        self.assertEqual(output1, s)
         self.assertIsInstance(output2, str)
-        self.assertEqual(output2, input)
+        self.assertEqual(output2, s)
         self.assertIsInstance(output3, bool)
         self.assertTrue(output3)
         self.assertIsInstance(output4, bool)
@@ -1072,8 +1075,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertEqual(row, (value, 'hello'))
 
     def test_json(self):
-        inval = {"employees":
-            [{"firstName": "John", "lastName": "Doe", "age": 61}]}
+        inval = {"employees": [
+            {"firstName": "John", "lastName": "Doe", "age": 61}]}
         table = self.table_prefix + 'booze'
         con = self._connect()
         try:
@@ -1092,8 +1095,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         self.assertEqual(inval, outval)
 
     def test_jsonb(self):
-        inval = {"employees":
-            [{"firstName": "John", "lastName": "Doe", "age": 61}]}
+        inval = {"employees": [
+            {"firstName": "John", "lastName": "Doe", "age": 61}]}
         table = self.table_prefix + 'booze'
         con = self._connect()
         try:
@@ -1134,6 +1137,30 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         sql = 'select 1'  # cannot be executed after connection is closed
         self.assertRaises(pgdb.OperationalError, cur.execute, sql)
 
+    def test_fetchall_with_various_sizes(self):
+        # we test this because there are optimizations based on result size
+        con = self._connect()
+        try:
+            for n in (1, 3, 5, 7, 10, 100, 1000):
+                cur = con.cursor()
+                try:
+                    cur.execute('select n, n::text as s, n %% 2 = 1 as b'
+                                ' from generate_series(1, %d) as s(n)' % n)
+                    res = cur.fetchall()
+                    self.assertEqual(len(res), n, res)
+                    self.assertEqual(len(res[0]), 3)
+                    self.assertEqual(res[0].n, 1)
+                    self.assertEqual(res[0].s, '1')
+                    self.assertIs(res[0].b, True)
+                    self.assertEqual(len(res[-1]), 3)
+                    self.assertEqual(res[-1].n, n)
+                    self.assertEqual(res[-1].s, str(n))
+                    self.assertIs(res[-1].b, n % 2 == 1)
+                finally:
+                    cur.close()
+        finally:
+            con.close()
+
     def test_fetchmany_with_keep(self):
         con = self._connect()
         try:
@@ -1159,6 +1186,12 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         finally:
             con.close()
 
+    def help_nextset_setUp(self, _cur):
+        pass  # helper not needed
+
+    def help_nextset_tearDown(self, _cur):
+        pass  # helper not needed
+
     def test_nextset(self):
         con = self._connect()
         cur = con.cursor()
@@ -1223,7 +1256,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             try:
                 cur = con.cursor()
                 if autocommit:
-                    cur.execute("truncate %s" % table)
+                    cur.execute("truncate table %s" % table)
                 else:
                     cur.execute(
                         "create table %s (n smallint check(n!=4))" % table)
@@ -1307,7 +1340,7 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
         data = ('hello', 'world')
         con = self._connect()
         cur = con.cursor()
-        cur.build_row_factory = lambda: tuple
+        cur.build_row_factory = lambda: tuple  # noqa: E731
         cur.execute("select %s, %s", data)
         row = cur.fetchone()
         self.assertEqual(row, data)
@@ -1336,8 +1369,8 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
                 info = pgdb._row_factory.cache_info()
                 self.assertEqual(info.maxsize, maxsize)
                 self.assertEqual(info.hits + info.misses, 6)
-                self.assertEqual(info.hits,
-                    0 if maxsize is not None and maxsize < 2 else 4)
+                self.assertEqual(
+                    info.hits, 0 if maxsize is not None and maxsize < 2 else 4)
 
     def test_memory_leaks(self):
         ids = set()
@@ -1355,6 +1388,44 @@ class test_PyGreSQL(dbapi20.DatabaseAPI20Test):
             objs[:] = [obj for obj in objs if repr(obj) != '(<NULL>,)']
         self.assertEqual(len(objs), 0)
 
+    def test_cve_2018_1058(self):
+        # internal queries should use qualified table and operator names,
+        # see https://nvd.nist.gov/vuln/detail/CVE-2018-1058
+        con = self._connect()
+        cur = con.cursor()
+        execute = cur.execute
+        try:
+            execute("SET client_min_messages TO WARNING")
+            execute("SET TIMEZONE TO 'UTC'")
+            execute("SHOW TIMEZONE")
+            self.assertEqual(cur.fetchone()[0], 'UTC')
+            execute("""
+                CREATE OR REPLACE FUNCTION public.bad_eq(oid, integer)
+                RETURNS boolean AS $$
+                BEGIN
+                  SET TIMEZONE TO 'CET';
+                  RETURN oideq($1, $2::oid);
+                END
+                $$ LANGUAGE plpgsql
+                """)
+            execute("DROP OPERATOR IF EXISTS public.= (oid, integer)")
+            execute("""
+                CREATE OPERATOR public.= (
+                  PROCEDURE = public.bad_eq,
+                  LEFTARG = oid, RIGHTARG = integer
+                );
+                """)
+            # the following select changes the time zone as a side effect if
+            # internal query uses unqualified = operator as it did earlier
+            execute("SELECT 1")
+            execute("SHOW TIMEZONE")  # make sure time zone has not changed
+            self.assertEqual(cur.fetchone()[0], 'UTC')
+        finally:
+            execute("DROP OPERATOR IF EXISTS public.= (oid, integer)")
+            execute("DROP FUNCTION IF EXISTS public.bad_eq(oid, integer)")
+            cur.close()
+            con.close()
+
 
 if __name__ == '__main__':
     unittest.main()
